---
title: '[공지] PortOne(포트원)이 새롭게 출발합니다!'
category: 공지사항
tags:
  - 공지사항
datetime: 2023-02-05T15:00:00.000Z
---

2023년 2월 6일, 아임포트는 PortOne(포트원)으로 새로운 시작을 알립니다.

포트원은 통합 결제 솔루션으로 고객의 비즈니스 성장 단계에 맞춰 결제와 관련된 모든 문제를 해결하고자 합니다.\
포트원은 어렵고, 복잡했던 결제 시장에 ‘이제, 결제도 얼마든지 간편할 수 있다’는 새로운 경험을 선사합니다.

주식회사 아임포트가 <Highlight text="주식회사 코리아포트원" />으로 법인명을 변경했습니다.\
이에 따른 변경사항을 안내드리오니, 서비스 이용에 참고하시기 바랍니다.

<Callout icon="️⭐" title="변경 사항" content="법인명 : 주식회사 코리아포트원
서비스명 :  PortOne (포트원)
신규 홈페이지 : https://portone.io
서비스 주소 아임포트의 서비스 주소가 새롭게 변경되며, 기존 서비스 주소로 접속하시면 새로운 서비스 주소로 자동으로 연결됩니다.

**변경된 서비스 주소**
✔ 관리자콘솔 클래식 - https://classic-admin.portone.io
✔ 관리자콘솔 V2 - https://admin.portone.io
✔ Analytics - https://analytics.portone.io
✔ 결제 데모 - https://sdk-playground.portone.io

※  아임포트 API와 SDK를 포함한 기존 이용 중인 서비스는 모두 정상적으로 이용 가능합니다." />

💡FAQ

<Highlight text="   Q.  아임포트가 다른 기업에 인수/합병됐나요?" />

A. 아니요. 주식회사 아임포트가 리브랜딩 되며 주식회사 코리아포트원으로 법인명을 변경했습니다. 이에 따라 서비스명을 아임포트에서 >> PortOne(포트원)으로 변경했습니다.

<Highlight text="Q. iamport.kr 도메인이 포함된 API 또는 SDK 를 그대로 이용 가능한가요?" />

A. 네, 가능합니다. [iamport.kr](http://iamport.kr/) 도메인의 API 또는 SDK 그대로 사용 가능합니다.

<Highlight text="Q. iamport.kr 도메인의 API 또는 SDK 에서 portone.io로 도메인을 변경하여 호출해도 되나요?" />

A. 아니요. 기존 이용 중인 API 또는 SDK 는 도메인 수정 없이 이용해야 합니다.

포트원은 2023년에도 고객과 함께 성장하겠습니다.

새롭게 변경된 포트원에 대해 궁금한 점이 있으시다면 아래로 문의 부탁드립니다.

•일반문의 <cs@portone.io>

•기술지원 <support@portone.io>
